# $Id: 20-archive_auto_qc_to_db.t 13506 2011-07-01 09:19:27Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 11;
use Test::Exception;
use lib qw{t};
use t::util;
use npg::api::run;

use_ok('npg_pipeline::archive::qc::auto_qc');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_API_UTIL} = $util->apiutil();
$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();

my $analysis_runfolder_path = $util->analysis_runfolder_path();

sub create_analysis {
  `rm -rf /tmp/nfs/sf45`;
  `mkdir -p $analysis_runfolder_path/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive`;
  `mkdir $analysis_runfolder_path/Config`;
  `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $analysis_runfolder_path/`;
  `ln -s Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto $analysis_runfolder_path/Latest_Summary`;

  return 1;
}


{
  my $aaq;

  lives_ok { $aaq = npg_pipeline::archive::qc::auto_qc->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 0,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{created with run_folder ok};
  isa_ok($aaq, q{npg_pipeline::archive::qc::auto_qc}, q{$aaq});
  create_analysis();

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my @jids;
  lives_ok { @jids = $aaq->submit_to_lsf($arg_refs); } q{no croak submitting job to lsf};

  is(scalar@jids, 1, q{only one job submitted});

  my $bsub_command = $util->drop_temp_part_from_paths( $aaq->_generate_bsub_command($arg_refs) );
  my $expected_cmd = q{bsub -q test -w'done(123) && done(321)' -J autoqc_loader_1234_20090709-123456 -R 'rusage[nfs_12=1]' -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/autoqc_loader_1234_20090709-123456.out 't/bin/software/solexa/bin/autoqc_loader --id_run=1234 --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc'};

  is( $bsub_command, $expected_cmd, q{generated bsub command is correct} );
}

{
   $ENV{TEST_RUN_OBJECT} = npg::api::run->new({
    util => $util->apiutil(),
    id_run => 1234,
  });

  my $args = {};
  $args->{qc_dir} = [2,3,5];

  $util->create_multiplex_analysis($args);

  my $aaq;
  lives_ok { $aaq = npg_pipeline::archive::qc::auto_qc->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose   => 0,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{created with run_folder ok};
  isa_ok($aaq, q{npg_pipeline::archive::qc::auto_qc}, q{$aaq});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my @jids;
  lives_ok { @jids = $aaq->submit_to_lsf($arg_refs); } q{no croak submitting job to lsf};

  is(scalar@jids, 1, q{only one job submitted});

  my $bsub_command = $util->drop_temp_part_from_paths( $aaq->_generate_bsub_command($arg_refs) );
  my $expected_cmd = q{bsub -q test -w'done(123) && done(321)' -J autoqc_loader_1234_20090709-123456 -R 'rusage[nfs_12=1]' -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/autoqc_loader_1234_20090709-123456.out 't/bin/software/solexa/bin/autoqc_loader --id_run=1234 --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/qc --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane2 --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane2/qc --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane3 --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane3/qc --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane5 --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/lane5/qc --path=/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto'};

  is( $bsub_command, $expected_cmd, q{generated bsub command is correct} );

  #$util->remove_staging; 
}

1;
