# $Id: 20-archive_file_generation-md5.t 13506 2011-07-01 09:19:27Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 17;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;

use_ok('npg_pipeline::archive::file::generation::md5');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();

$ENV{TEST_API_UTIL} = $util->apiutil();

$ENV{TEST_RUN_OBJECT} = npg::api::run->new({
    util => $util->apiutil(),
    id_run => 1234,
  });

{

  my $md5_generator = npg_pipeline::archive::file::generation::md5->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  });
  isa_ok($md5_generator, q{npg_pipeline::archive::file::generation::md5}, q{$md5_generator});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  $util->create_analysis();

  my @jids;
  eval { @jids = $md5_generator->generate($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak running generate});
  is(scalar@jids, 2, q{2 job ids returned});

  my $bsub_command = $util->drop_temp_part_from_paths( $md5_generator->_generate_bsub_command( $arg_refs ) );
  my $expected_command = q{bsub -q test -R 'rusage[nfs_12=4]' -w'done(123) && done(321)' -J md5_1234_split_nc_lanes_20090709-123456[7] -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/md5_1234_split_nc_lanes_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/npg_pipeline_create_md5  --archive_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive --basecall_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/BaseCalls --bustard_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto --conf_path data/config_files --data_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data --default_usr_bin t/bin/t/bin/usr/bin --domain test --expected_cycle_count 37 --filenames 1234_`echo $LSB_JOBINDEX`.fastq --filenames 1234_`echo $LSB_JOBINDEX`.fastqcheck --fs_resource nfs_12 --id_run 1234 --intensity_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto --internal_script_bin t/bin/software/solexa/bin --lane_count 8 --lsf_queue test --name IL2_1234 --pb_cal_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/PB_cal --recalibrated_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto --run_folder 123456_IL2_1234 --runfolder_path /nfs/sf45/IL2/analysis/123456_IL2_1234 --use_bases Y37 --verbose  --md5_file_name 1234_`echo $LSB_JOBINDEX`.md5'};

  is( $bsub_command, $expected_command, q{generated bsub command is correct} );
}

{

  my $md5_generator = npg_pipeline::archive::file::generation::md5->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    lane => 4,
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  });
  isa_ok($md5_generator, q{npg_pipeline::archive::file::generation::md5}, q{$md5_generator});

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  $util->create_analysis();
  my @jids;
  eval { @jids = $md5_generator->generate($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak running generate});
  is(scalar@jids, 1, q{1 job id returned});

  $arg_refs->{lane_group} = [4]; # because the arg_refs won't have anything in it

  my $bsub_command = $util->drop_temp_part_from_paths( $md5_generator->_generate_bsub_command( $arg_refs ) );
  my $expected_command = q{bsub -q test -R 'rusage[nfs_12=4]' -w'done(123) && done(321)' -J md5_1234_split_nc_lanes_20090709-123456[4] -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive/log/md5_1234_split_nc_lanes_20090709-123456.%I.%J.out 't/bin/software/solexa/bin/npg_pipeline_create_md5  --archive_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive --basecall_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/BaseCalls --bustard_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto --conf_path data/config_files --data_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data --default_usr_bin t/bin/t/bin/usr/bin --domain test --expected_cycle_count 37 --filenames 1234_`echo $LSB_JOBINDEX`.fastq --filenames 1234_`echo $LSB_JOBINDEX`.fastqcheck --fs_resource nfs_12 --id_run 1234 --intensity_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto --internal_script_bin t/bin/software/solexa/bin --lane 4 --lane_count 8 --lsf_queue test --name IL2_1234 --pb_cal_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/PB_cal --recalibrated_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto --run_folder 123456_IL2_1234 --runfolder_path /nfs/sf45/IL2/analysis/123456_IL2_1234 --use_bases Y37 --verbose  --md5_file_name 1234_`echo $LSB_JOBINDEX`.md5'};

  is( $bsub_command, $expected_command, q{generated bsub command is correct} );
}

my $href = $util->set_rta_staging_analysis_area();

$href->{run_folder} = q{123456_IL2_1234};
$href->{timestamp} = q{20090709-123456};
$href->{lane} = 4;
$href->{verbose} = 1;
$href->{conf_path} = $conf_path;

{
  $href->{filenames} = [ qw{
      1234_4.fastq
      1234_4.fastqcheck
    } ];

  my $md5_generator = npg_pipeline::archive::file::generation::md5->new( $href );
  isa_ok($md5_generator, q{npg_pipeline::archive::file::generation::md5}, q{$md5_generator});

  lives_ok {
    $md5_generator->generate_md5s();
  } q{generate_md5s is ok - but no md5 filename};
}
{
  $href->{md5_file_name} = q{1234_4.md5};
  delete $href->{filenames};

  my $md5_generator = npg_pipeline::archive::file::generation::md5->new( $href );
  isa_ok($md5_generator, q{npg_pipeline::archive::file::generation::md5}, q{$md5_generator});

  lives_ok {
    $md5_generator->generate_md5s();
  } q{generate_md5s is ok - but no filenames};
}
{
  $href->{filenames} = [ qw{
      1234_4.fastq
      1234_4.fastqcheck
    } ];

  my $md5_generator = npg_pipeline::archive::file::generation::md5->new( $href );
  isa_ok($md5_generator, q{npg_pipeline::archive::file::generation::md5}, q{$md5_generator});

  my $archive_path = $md5_generator->archive_path();
  qx{mkdir $archive_path};

  qx{touch $archive_path/1234_4.fastqcheck};
  qx{touch $archive_path/1234_4.fastq};
  qx{echo '76d9a038f4147aea845e3c186566790d *' >> $archive_path/1234_4.fastq.md5};

  lives_ok {
    $md5_generator->generate_md5s();
  } q{generate_md5s is ok};

  $md5_generator->_set_is_split_lane( 1 );

  lives_ok {
    $md5_generator->generate_md5s();
  } q{generate_md5s is ok};

  qx{rm -f $archive_path/1234_4.md5};
  push @{ $href->{filenames} }, qw{
      1234_4_nonhuman.fastq
    };

  lives_ok {
    $md5_generator->generate_md5s();
  } q{generate_md5s is ok};

}
1;
