# $Id: 20-archive_summary_loader.t 13506 2011-07-01 09:19:27Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 7;
use Test::Exception;
use lib qw{t};
use t::util;
use npg::api::run;

use_ok('npg_pipeline::archive::qc::summary_loader');

my $util = t::util->new();
my $conf_path = $util->conf_path();

$ENV{TEST_API_UTIL} = $util->apiutil();
$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
my $tmp_dir = $util->temp_directory();

my $analysis_runfolder_path = $util->analysis_runfolder_path();

sub create_analysis {
  `rm -rf $tmp_dir/nfs/sf45`;
  `mkdir -p $analysis_runfolder_path/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/archive`;
  `mkdir $analysis_runfolder_path/Config`;
  `cp t/data/Recipes/TileLayout.xml $analysis_runfolder_path/Config/`;
  `cp t/data/Recipes/Recipe_GA2_37Cycle_PE_v6.1.xml $analysis_runfolder_path/`;
  `ln -s Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto $analysis_runfolder_path/Latest_Summary`;

  return 1;
}

{
  my $asl;

  lives_ok { $asl = npg_pipeline::archive::qc::summary_loader->new({
    run_folder => q{123456_IL2_1234},
    timestamp => q{20090709-123456},
    verbose => 1,
    conf_path => $conf_path,
    domain => q{test},
  }); } q{created with run_folder ok};
  isa_ok($asl, q{npg_pipeline::archive::qc::summary_loader}, q{$asl});
  $util->create_analysis();

  my $arg_refs = {
    required_job_completion => q{-w'done(123) && done(321)'},
  };

  my @jids;
  lives_ok { @jids = $asl->submit_to_lsf($arg_refs); } q{no croak submitting job to lsf};

  is(scalar@jids, 1, q{only one job submitted});
  is($jids[0], q[5d34729c59a5be463e4a64b9091a9828], q{returned job id is correct});

  my $bsub_command = $util->drop_temp_part_from_paths( $asl->_generate_bsub_command($arg_refs) );
  my $expected_command = q{bsub -q test -w'done(123) && done(321)' -J summary_loader_1234_20090709-123456 -R 'rusage[nfs_12=1]' -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/log/summary_loader_1234_20090709-123456.out 't/bin/software/solexa/bin/summary_loader --basecall_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/BaseCalls --bustard_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto --data_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data --fs_resource nfs_12 --id_run 1234 --intensity_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto --name IL2_1234 --pb_cal_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/PB_cal --recalibrated_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto --run_folder 123456_IL2_1234 --runfolder_path /nfs/sf45/IL2/analysis/123456_IL2_1234 --tag_qseqs_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/C1-18-Firecrest1.3.4_09-07-2009_auto/Bustard1.3.4_09-07-2009_auto/GERALD_09-07-2009_auto/tag_qseqs --verbose '};
  is( $bsub_command, $expected_command, q{generated bsub command is correct});
}
1;