# $Id: 25-analysis-multiplex.t 13506 2011-07-01 09:19:27Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 19;
use Test::Exception::LessClever;
use lib qw{t};
use t::util;
use npg::api::run;

my $util = t::util->new();
$util->catch_email();
my $conf_path = $util->conf_path();

$ENV{TEST_BIN} = q{t/bin/};
$ENV{TEST_DIR} = $util->temp_directory();
$ENV{TEST_FS_RESOURCE} = q{nfs_12};

BEGIN {
  use_ok(q{npg_pipeline::analysis::multiplex});
}

$ENV{TEST_API_UTIL} = $util->apiutil();

my $runfolder_path = $util->analysis_runfolder_path();
my $req_job_completion = q{-w'done(123) && done(321)'};

{
  $util->set_rta_staging_analysis_area();
  my $multiplex;
  lives_ok {
    $multiplex = npg_pipeline::analysis::multiplex->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      conf_path => $conf_path,
      domain => q{test},
    });
  } q{no croak creating new object};
  isa_ok($multiplex, q{npg_pipeline::analysis::multiplex}, q{$multiplex});

  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  my @job_ids;
  lives_ok { @job_ids = $multiplex->submit_index_decoder_jobs($arg_refs);  } q{no croak submit_index_decoder_jobs with a run which is not multiplexed};
  is(scalar@job_ids, 0, q{returned from submit_index_decoder_jobs with no job_ids});

  is($util->drop_temp_part_from_paths( $multiplex->bustard_original_qseq_dir() ), q{/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/bustard_original_qseq_dir}, q{bustard_original_qseq_dir ok});

}

{
  $util->multiplexed_rta_pre_gerald();
  my $multiplex;
  lives_ok {
    $multiplex = npg_pipeline::analysis::multiplex->new({
      id_run => 1234,
      run_folder => q{123456_IL2_1234},
      timestamp => q{20091028-101635},
      lsf_queue => q{test},
      verbose => 1,
      tag_file => $runfolder_path .q{/tag_set},
      conf_path => $conf_path,
      domain => q{test},
      #recalibrated_path => $recalibrated_path,
    });
  } q{no croak creating new object};
  isa_ok($multiplex, q{npg_pipeline::analysis::multiplex}, q{$multiplex});

  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  my @job_ids;
  lives_ok { @job_ids = $multiplex->submit_index_decoder_jobs($arg_refs);  } q{no croak submit_index_decoder_jobs with a run which is multiplexed};
  is(scalar@job_ids, 1, q{returned from index_decoder with 1 job_id});

  my $test_bsub_command = q{bsub -q test -w'done(123) && done(321)' -R 'rusage[nfs_12=1]' -J npg_pipeline_decode_bustard_multiplex_1234_20091028-101635[1-8] -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/log/npg_pipeline_decode_bustard_multiplex_1234_20091028-101635.%I.%J.out 't/bin/software/solexa/bin/npg_pipeline_decode_bustard_multiplex --lane `echo $LSB_JOBINDEX` --bustard_path /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA --bustard_home Data/Intensities --bustard_original_qseq_dir /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/bustard_original_qseq_dir --conf_path data/config_files --domain test --expected_cycle_count 160 --fs_resource nfs_12 --id_run 1234 --internal_script_bin t/bin/software/solexa/bin --is_indexed  --lane_count 8 --run_folder 123456_IL2_1234 --runfolder_path /nfs/sf45/IL2/analysis/123456_IL2_1234 --runtype RTA --tag_file /nfs/sf45/IL2/analysis/123456_IL2_1234/tag_set --timestamp 20091028-101635 --use_bases Y76,I7n,y76 --verbose '};
  is($util->drop_temp_part_from_paths( $multiplex->_generate_bsub_command($arg_refs) ), $test_bsub_command, q{generated bsub command for lane 8 is correct});

}

{
  $util->multiplexed_rta_pre_gerald();
  my $multiplex = npg_pipeline::analysis::multiplex->new({
    id_run => 1234,
    run_folder => q{123456_IL2_1234},
    timestamp => q{20091028-101635},
    lsf_queue => q{test},
    verbose => 1,
    lane => 8,
    conf_path => $conf_path,
    domain => q{test},
  });

  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  my $tag_file;
  throws_ok {
    $tag_file = $multiplex->get_tag_file();
  } qr{You[ ]have[ ]not[ ]provided[ ]an[ ]index[ ]length[ ]and[ ]there[ ]is[ ]no[ ]preset[ ]tag_file[ ]or[ ]lane[ ]specific[ ]tag[ ]file[ ]found[.]},
  q{no tag file can be determined};

  my $runfolder_path = $multiplex->runfolder_path();
  my $specific_tag_file = qq{$runfolder_path/lane_8.tag};
  qx[cp t/data/tag_files/lane_8.tag $runfolder_path/];
  lives_ok {
    $tag_file = $multiplex->get_tag_file();
  } q{tag file found};
  is($tag_file, $specific_tag_file, q{correct specific tag file found});

}

{
  $util->multiplexed_rta_pre_gerald();
  my $multiplex = npg_pipeline::analysis::multiplex->new({
    id_run => 1234,
    run_folder => q{123456_IL2_1234},
    timestamp => q{20091028-101635},
    lsf_queue => q{test},
    verbose => 1,
    tag_file => $runfolder_path .q{/tag_set},
    lane => 8,
    conf_path => $conf_path,
    domain => q{test},
    #recalibrated_path => $recalibrated_path,
  });
  is($util->drop_temp_part_from_paths( $multiplex->bustard_original_qseq_dir() ), q{/nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/bustard_original_qseq_dir}, q{bustard_original_qseq_dir ok});

  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  my $command = q{t/bin/software/solexa/bin/index_decoder -t /nfs/sf45/IL2/analysis/123456_IL2_1234/tag_set -u Y76,I7n,y76 -o /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/bustard_original_qseq_dir/s_8_?_????_qseq.txt};

  is($util->drop_temp_part_from_paths( $multiplex->_index_decoder_command() ), $command, q{correct index_decoder command generated for lane 8});

  lives_ok { $multiplex->index_decode(); } q{no croak for index_decode};

  my $bustard_path      = $multiplex->bustard_path();
  my $recalibrated_path = $multiplex->recalibrated_path();

  foreach my $lane (1..8) {
    foreach my $cycle (qw{1 2 t}) {
      my $filename = qq{s_${lane}_${cycle}_0001_qseq};
      qx[ln -s $bustard_path/$filename.txt $recalibrated_path/${filename}_custom.txt];
    }
  }

#  lives_ok { $multiplex->rename_files_from_indexed_names(); } q{no croak for rename_files_from_indexed_names};


}

{
  $util->multiplexed_rta_pre_gerald();
  qx[touch ${runfolder_path}/lane_8.tag];
  my $multiplex = npg_pipeline::analysis::multiplex->new({
    id_run => 1234,
    run_folder => q{123456_IL2_1234},
    timestamp => q{20091028-101635},
    lsf_queue => q{test},
    verbose => 1,
    tag_file => $runfolder_path .q{/lane_8.tag},
    lane => 8,
    conf_path => $conf_path,
    domain => q{test},
  });

  my $arg_refs = {
    required_job_completion => $req_job_completion,
  };

  my $command = q{cp /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA/bustard_original_qseq_dir/s_8_?_????_qseq.txt /nfs/sf45/IL2/analysis/123456_IL2_1234/Data/Intensities/Bustard1.5.1_09-07-2009_RTA};

  is( $util->drop_temp_part_from_paths( $multiplex->_index_decoder_command() ), $command, q{correct index_decoder command generated for lane 8});

  lives_ok { $multiplex->index_decode(); } q{no croak for index_decode};

}


1;
__END__
