# $Id: 30-run_calibration.t 13506 2011-07-01 09:19:27Z ajb $
use strict;
use warnings;
use Carp;
use English qw{-no_match_vars};
use Test::More tests => 18;
use Test::Exception;
use lib qw{t};
use t::util;
use File::Slurp;

use_ok('npg_pipeline::run::calibration');

my $util = t::util->new();
my $runfolder_path = $util->analysis_runfolder_path();
$ENV{TEST_USERAGENT} = $runfolder_path . q{/useragent};

{
  my $r_cal;
  lives_ok {
    $r_cal = npg_pipeline::run::calibration->new({
      id_run => 1234,
      conf_path => $util->conf_path(),
      domain => q{test},
    });
  } q{no croak on creation};
  isa_ok($r_cal, q{npg_pipeline::run::calibration}, q{$r_cal});

  $r_cal->make_log_dir( $runfolder_path );
  write_file( $ENV{TEST_USERAGENT}, $util->serialized_useragent() );


  my $api_run = $r_cal->run();
  isa_ok($api_run, q{npg::api::run}, q{$api_run});
  my $test_ua = $api_run->util->useragent();
  isa_ok($api_run->util->useragent(), q{t::useragent}, q{useragent});
  my $batch;
  lives_ok { $batch = $r_cal->batch(); } q{no croak obtaining a batch};
  isa_ok($batch, q{st::api::batch}, q{$r_cal->_batch()});
  is($batch->id(), 2015, q{correct batch_id});
  is($r_cal->batch(), $batch, q{cache ok});
  $batch->useragent($test_ua);
  isa_ok($batch->useragent(), q{t::useragent}, q{st useragent});
  my $lanes;
  lives_ok { $lanes = $r_cal->_lanes(); } q{no croak obtaining lanes};

  isa_ok($lanes->[0], q{st::api::lane}, q{first lane});
  isa_ok($lanes->[3], q{st::api::lane}, q{fourth lane});
  my @job_ids;
  my $href = $r_cal->_is_spiked_store();
#  $r_cal->{_is_spiked} = {};
  foreach my $l (1..8) {
#    $r_cal->{_is_spiked}->{$l} = 0;
    $href->{$l} = 0;
  }
  my $arg_refs = {};
  $arg_refs->{required_job_completion}  = q{-w'done(123) && done(321)'};
  $arg_refs->{timestamp}                = q{20090709-123456};
  eval { @job_ids = $r_cal->create_table($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak on create_table call});
# for the moment, these two are dead until the st::api is sorted to the new seqscape
  is(scalar@job_ids, 1, q{one job id});
  is($job_ids[0], 4, q{control lane});
  eval { @job_ids = $r_cal->apply_table($arg_refs); };
  is($EVAL_ERROR, q{}, q{no croak on apply_table call});
  is(scalar@job_ids, 8, q{8 job ids});
}
1;